#define CUSTOM_SETTINGS
#define INCLUDE_GAMEPAD_MODULE
#include <Dabble.h>
#include <Wire.h>
#include <Arduino.h>
#include <VL53L0X.h>
#include <Servo.h>
#include <L298N.h>

// Motor A
int enA = 6;
int in1 = 7;
int in2 = 8;

// Motor B
int in3 = 9;
int in4 = 10;
int enB = 11;

L298N motor1(enA, in1, in2);
L298N motor2(enB, in3, in4);

Servo myservo;
VL53L0X sensor;
bool sensorIngeschakeld = false;
int servoPositie = 0;

void setup() {
  Serial.begin(9600);      
  Dabble.begin(9600);

  Wire.begin();
  Wire.setClock(5000);
  sensor.init();
  sensor.setTimeout(500);
  
  motor1.setSpeed(200);
  motor2.setSpeed(200);

  myservo.attach(5);
}

void moveServo(int start, int end, int stepDelay) {
  if (start < end) {
    for (int pos = start; pos <= end; pos++) {
      myservo.write(pos);
      delay(stepDelay);
    }
  } else {
    for (int pos = start; pos >= end; pos--) {
      myservo.write(pos);
      delay(stepDelay);
    }
  }
}

void loop() {
  Dabble.processInput();
  
  if (GamePad.isStartPressed()) {
    sensorIngeschakeld = true;
    Serial.print("Start");
  }

  if (GamePad.isSelectPressed()) {
    sensorIngeschakeld = false;
    Serial.print("Select");
  }

  if (sensorIngeschakeld) {
    uint16_t huidigeAfstand = sensor.readRangeSingleMillimeters();
    if (sensor.timeoutOccurred()) {
      Serial.print("Timeout occurred");
    } else {
      if (huidigeAfstand < 100) {
        if (servoPositie != 0) {
          moveServo(servoPositie, 0, 5);
          servoPositie = 0;
          Serial.print("Afstand is minder dan 10 cm");
        }
      } else {
        if (servoPositie != 180) {
          moveServo(servoPositie, 180, 5);
          servoPositie = 180;
        }
      }
    }
  } else {
    if (GamePad.isSquarePressed())
    {
      moveServo(servoPositie, 180, 5);    
      servoPositie = 180;
      Serial.print("Square");
    }

    if (GamePad.isCirclePressed())
    {
      moveServo(servoPositie, 0, 5);
      servoPositie = 0;
      Serial.print("Circle");
    }

    if (GamePad.isTrianglePressed())
    {
      moveServo(servoPositie, 90, 5);
      servoPositie = 90;
      Serial.print("Triangle");
    }
  }

  if (GamePad.isUpPressed()) {
    motor1.forward();
    motor2.forward();
    Serial.print("UP");
  } else if (GamePad.isDownPressed()) {
    motor1.backward();
    motor2.backward();
    Serial.print("DOWN");
  } else if (GamePad.isLeftPressed()) {
    motor1.forward();
    motor2.backward();
    Serial.print("Left");
  } else if (GamePad.isRightPressed()) {
    motor1.backward();
    motor2.forward();
    Serial.print("Right");
  } else {
    motor1.stop();
    motor2.stop();
    Serial.print("STOP");
  }

  if (GamePad.isCrossPressed())
  {
    Serial.print("Cross");
  }
}